@@ -9,6 +9,7 @@ from dnora import utils
 
 # Import objects
 from dnora.grid import Grid, TriGrid
+from dnora.grid.mask import Edges
 
 from dnora.file_module import FileNames
 
@@ -62,6 +63,7 @@ if TYPE_CHECKING:
     from dnora.read.abstract_readers import ReaderFunction
 from dnora.type_manager.dnora_objects import dnora_objects
 
+
 def start_and_end_time_of_run(
     start_time: Optional[str],
     end_time: Optional[str],
@@ -146,6 +148,8 @@ class ModelRun:
         self._reference_time = None
         self.name = name
         self._post_processing = None
+        self._nest = {}
+        self._parent = None
 
         self.plot = dnplot.Matplotlib(self)
         self._dnora_objects: dict[DnoraDataType, DnoraObject] = {
@@ -624,7 +628,6 @@ class ModelRun:
                 return
 
         name = self.spectra1d().name
-        self.spectra1d().set_convention(SpectralConvention.MET)
         waveseries_reader = Spectra1DToWaveSeries(self.spectra1d(), freq)
 
         self.import_waveseries(
@@ -737,6 +740,41 @@ class ModelRun:
             name=DnoraDataType.SPECTRALGRID.name, freq=freq, dirs=dirs
         )
 
+    def set_nested_grid(self, grid: Grid) -> None:
+        """Sets up a nested run for the provided grid"""
+        if grid.name in self._nest.keys():
+            raise ValueError(f"A nested grid named '{grid.name}' allready exists!")
+
+        self._nest[grid.name] = self.__class__(
+            grid, start_time=self.start_time(), end_time=self.end_time()
+        )
+        msg.header(
+            self.nest(get_dict=True)[grid.name],
+            f"Setting up a nested run {grid.name} inside {self.grid().name}...",
+        )
+        self.nest(get_dict=True)[grid.name].grid().set_boundary_points(
+            Edges(edges=["N", "W", "S", "E"])
+        )
+        self.nest(get_dict=True)[grid.name]._parent = self
+
+    def nest(self, get_dict: bool = False) -> ModelRun:
+        """Returns a dict of nested ModelRuns.
+
+        A single object is returned if:
+        Only one exists AND get_dict = False [default]"""
+
+        if get_dict or len(self._nest) > 1:
+            return self._nest
+        elif len(self._nest) == 1:
+            key, value = next(iter(self._nest.items()))
+            return value
+
+        return self._nest
+
+    def parent(self) -> ModelRun:
+        """Returns the parent ModelRun object of the nested ModelRun."""
+        return self._parent
+
     def spectral_grid(self) -> Ice:
         """Returns the spectral grid object if exists."""
         return self._dnora_objects.get(DnoraDataType.SPECTRALGRID)
@@ -890,7 +928,9 @@ class ModelRun:
         obj_type = data_type_from_string(obj_type)
         return self._dnora_objects.get(obj_type)
 
-    def __setitem__(self, obj_type: Union[DnoraDataType, str], value: DnoraObject) -> None:
+    def __setitem__(
+        self, obj_type: Union[DnoraDataType, str], value: DnoraObject
+    ) -> None:
         """Sets a Dnora item"""
         obj_type = data_type_from_string(obj_type)
         self._dnora_objects[obj_type] = value
